==> haskell-x509-1.7.2-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509
version: 1.7.2
id: x509-1.7.2-EVk4f2BV7NpJF8rKRYOGbC
key: x509-1.7.2-EVk4f2BV7NpJF8rKRYOGbC
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X509 reader and writer
description:
    X509 reader and writer
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.X509 Data.X509.EC
hidden-modules: Data.X509.Internal Data.X509.CertificateChain
                Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
                Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
                Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
                Data.X509.Signed
abi: 8743d5f25d2aa44c9bee266dde37dce6
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/x509-1.7.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/x509-1.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/x509-1.7.2
hs-libraries: HSx509-1.7.2-EVk4f2BV7NpJF8rKRYOGbC
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    memory-0.14.14-FiOA0zEQIqU9pMZGNyv72b
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH containers-0.5.10.2
    hourglass-0.2.10-F9F0uBDufctEafTNs2clkC
    pem-0.2.2-F8eKoZ8aUh0162dv1azAYf
    asn1-types-0.3.2-LgkmetgAMIL4hX4ew0nQgN
    asn1-encoding-0.9.5-A5G1GHuEVVgH8Bnh2Wt4mc
    asn1-parse-0.9.4-BvRXpak9mabHKoCUuZ4hF7
    cryptonite-0.24-6O2YBbNLStYJmwkq5zLEJx
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             memory-0.14.14-FiOA0zEQIqU9pMZGNyv72b=31288e97a1618db31ba2d3698d738018
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             hourglass-0.2.10-F9F0uBDufctEafTNs2clkC=945d6764ced94d1a6c501ad80342660a
             pem-0.2.2-F8eKoZ8aUh0162dv1azAYf=d4f1faacfc3b18597ef0d86d2b217bf5
             asn1-types-0.3.2-LgkmetgAMIL4hX4ew0nQgN=e62fe8281d8ff79f01d6e62081d00eac
             asn1-encoding-0.9.5-A5G1GHuEVVgH8Bnh2Wt4mc=902abc35a49a5adbdf7de8d2698b0cec
             asn1-parse-0.9.4-BvRXpak9mabHKoCUuZ4hF7=ddc64db622fc1dffa666c175f43d89e9
             cryptonite-0.24-6O2YBbNLStYJmwkq5zLEJx=f485729293cc44bcb426ebfe7176782a
haddock-interfaces: /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html: /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-1.7.2-20-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509
version: 1.7.2
id: x509-1.7.2-2y9vdaROq5z255WD9u8O5y
key: x509-1.7.2-2y9vdaROq5z255WD9u8O5y
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X509 reader and writer
description:
    X509 reader and writer
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.X509 Data.X509.EC
hidden-modules: Data.X509.Internal Data.X509.CertificateChain
                Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
                Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
                Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
                Data.X509.Signed
abi: aab3ed0278323eee2ce14dcdbb4d0a70
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/x509-1.7.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/x509-1.7.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/x509-1.7.2
hs-libraries: HSx509-1.7.2-2y9vdaROq5z255WD9u8O5y
depends:
    base-4.10.1.0 bytestring-0.10.8.2
    memory-0.14.14-4o8zyRHIoSnHzCBHYQGHAV
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH containers-0.5.10.2
    hourglass-0.2.11-9hppRSjW3ll8eqnGIG01km
    pem-0.2.2-F8eKoZ8aUh0162dv1azAYf
    asn1-types-0.3.2-E39k0CrD1P4KQkqPfBSF6h
    asn1-encoding-0.9.5-GzmkjQRXyRm18OHlr15ms9
    asn1-parse-0.9.4-6ZWKmYDibhPCUPosyVFmYN
    cryptonite-0.24-CQS9SB3Hce73SrYZ7gsC5w
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             memory-0.14.14-4o8zyRHIoSnHzCBHYQGHAV=cd1266467377c3b0ef3fabb0cb06b2c3
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             hourglass-0.2.11-9hppRSjW3ll8eqnGIG01km=e66c1bf3bb6c0e723a33754b5ad8307b
             pem-0.2.2-F8eKoZ8aUh0162dv1azAYf=d4f1faacfc3b18597ef0d86d2b217bf5
             asn1-types-0.3.2-E39k0CrD1P4KQkqPfBSF6h=a9f1a05d1b0787e2ecbebf6d3b81d7ad
             asn1-encoding-0.9.5-GzmkjQRXyRm18OHlr15ms9=06d5f74e8fb95510ae15ffdb365cab1f
             asn1-parse-0.9.4-6ZWKmYDibhPCUPosyVFmYN=e01ab71146a098ee9fb1377c0c8318ec
             cryptonite-0.24-CQS9SB3Hce73SrYZ7gsC5w=bc3f27819a05db49c9ea25f433ac8587
haddock-interfaces: /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html: /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
